Learn R Programming

cocorresp (version 0.4-4)

beetles: Carabid beetles and vascular plants in Dutch roadside verges

Description

Counts of 126 beetle taxa and abundances of 173 vascular plant taxa (expressed on the 1-9 van der Maarel scale) in 30 road-side verges in the Netherlands.

Usage

data(beetles)

data(plants)

data(verges)

Arguments

Details

This is the complete dataset of Raemakers et al (2001). ter Braak and Schaffers (2004) only analyse a subset of 91 beetle taxa.

Examples

Run this code
data(beetles)
data(plants)

Run the code above in your browser using DataLab