Learn R Programming

cocorresp (version 0.4-1)

fitted.symcoca: Fitted values of a Symmetric Co-Correpsondence analysis model.

Description

Calculates and extracts the fitted values of a Symmetric Co-Correpsondence analysis model.

Usage

# S3 method for symcoca
fitted(object, which = c("y1","y2"), …)

Arguments

object

an object of class "symcoca"

which

character; should the response or predictor scores be plotted. Can be specified in several ways: response choices are one from c("y", "Y", "y1", "response"); predictor choices are one from c("x", "X", "y2", "predictor").

arguments to be passed to other methods.

Value

A list with the following components:

Y

the fitted values for the “response” matrix.

X

the fitted values for the “predictor” matrix.

nam.dat

a vector containing the names of the “response” and “predictor” matrices respectively. Used for printing the results.

References

Ter Braak, C.J.F and Schaffers, A.P. (2004) Co-Correspondence Analysis: a new ordination method to relate two community compositions. Ecology 85(3), 834--846

See Also

The model fitting function coca

Examples

Run this code
# NOT RUN {
## symmetric CoCA
data(beetles)
data(plants)

## log transform the bettle data
beetles <- log(beetles + 1)

## fit the model
bp.sym <- coca(beetles ~ ., data = plants, method = "symmetric")

## fitted values
bp.fit <- fitted(bp.sym)
# }
# NOT RUN {
bp.fit
# }
# NOT RUN {
## fitted values for beetles only
beetle.fit <- fitted(bp.sym, which = "y1")
# }

Run the code above in your browser using DataLab