Learn R Programming

cocorresp (version 0.4-1)

weights.symcoca: Exctract CoCA model weights

Description

Extractor function to identify and select appropriate analysis weights from Co-correspondence Analysis models.

Usage

# S3 method for symcoca
weights(object, ...)

# S3 method for predcoca weights(object, ...)

Arguments

object

an object of class "symcoca" or "predcoca".

arguments passed to other methods. Not used.

Value

A numeric vector of common site weights is currently returned. These correspond to \(R_{0}\) in ter Braak and Schaffers (2004).

References

ter Braak, C.J.F and Schaffers, A.P. (2004) Co-Correspondence Analysis: a new ordination method to relate two community compositions. Ecology 85(3), 834--846.

See Also

envfit.coca uses these weights to estimate weighted correlations in ordination space. See coca for details on creating CoCA models.

Examples

Run this code
# NOT RUN {
## symmetric CoCA
data(beetles)
data(plants)

## log transform the bettle data
beetles <- log(beetles + 1)

## fit the model
bp.sym <- coca(beetles ~ ., data = plants, method = "symmetric")

## weights == R[0]
weights(bp.sym)
# }

Run the code above in your browser using DataLab