Learn R Programming

cocorresp (version 0.4-1)

coinertia: Co-inertia analysis

Description

Performs a co-inertia of the triplets \((Q_1,K_1,R_0)\) and \((Q_2,K_2,R_0)\).

Usage

coinertia(y, ...)

# S3 method for default coinertia(y, x, n.axes = NULL, weights = NULL, symmetric = FALSE, ...)

Arguments

y, x

matrices or data frames of the two data sets for which axes of covariance are sought.

n.axes

numeric; the number of coinertia axes to retain.

weights

a vector of weights for the samples. If NULL, weights are chosen from the row sums of y (symmetric = FALSE) or the average of the row sums of y and x (symmetric = TRUE).

symmetric

logical; should a symmetric set of weights be used. See Details.

arguments passed to other functions. Currently ignored.

Value

An object of class "coinertia", which is a list with the following components:

scores

a list of ordination scores, with components species and sites, each of which is a list with components Y and X that refer to the scores for the input matrices y and x respectively.

weights

numeric vector of row weights used in the analysis.

lambda

numeric vector of Eigenvalues.

n.axes

numeric; the number of coinertia axes extracted

symmetric

logical; was a symmetric analysis performed?

call

the matched call.

References

Ter Braak, C.J.F and Schaffers, A.P. (2004) Co-Correspondence Analysis: a new ordination method to relate two community compositions. Ecology 85(3), 834--846

Doledec, S and Chessel, D. (1994) Co-inertia analysis: a method for studying species-environment relationships. Freshwater Biology 31, 277--294

See Also

symcoca for the function that calls fitCoinertia and coinertiaI for co-inertia analysis using identity matrices for \(K_1\), \(K_2\), and \(R_0\).

Examples

Run this code
# NOT RUN {
data(beetles, plants)
coin <- coinertia(beetles, plants)
coin
# }

Run the code above in your browser using DataLab