Performs a co-inertia of the triplets \((Q_1,K_1,R_0)\) and \((Q_2,K_2,R_0)\).
coinertia(y, ...)# S3 method for default
coinertia(y, x, n.axes = NULL, weights = NULL,
symmetric = FALSE, ...)
matrices or data frames of the two data sets for which axes of covariance are sought.
numeric; the number of coinertia axes to retain.
a vector of weights for the samples. If NULL,
weights are chosen from the row sums of y (symmetric =
FALSE) or the average of the row sums of y and x
(symmetric = TRUE).
logical; should a symmetric set of weights be used. See Details.
arguments passed to other functions. Currently ignored.
An object of class "coinertia", which is a list with the
following components:
a list of ordination scores, with components
species and sites, each of which is a list with
components Y and X that refer to the scores for the
input matrices y and x respectively.
numeric vector of row weights used in the analysis.
numeric vector of Eigenvalues.
numeric; the number of coinertia axes extracted
logical; was a symmetric analysis performed?
the matched call.
Ter Braak, C.J.F and Schaffers, A.P. (2004) Co-Correspondence Analysis: a new ordination method to relate two community compositions. Ecology 85(3), 834--846
Doledec, S and Chessel, D. (1994) Co-inertia analysis: a method for studying species-environment relationships. Freshwater Biology 31, 277--294
symcoca for the function that calls
fitCoinertia and coinertiaI for co-inertia analysis
using identity matrices for \(K_1\), \(K_2\), and \(R_0\).
# NOT RUN {
data(beetles, plants)
coin <- coinertia(beetles, plants)
coin
# }
Run the code above in your browser using DataLab