Learn R Programming

cocorresp (version 0.4-6)

fitCoinertia: Co-inertia analysis

Description

Performs a co-inertia of the triplets \((Q_1,K_1,R_0)\) and \((Q_2,K_2,R_0)\).

Usage

fitCoinertia(X, Dp, Y, Dq, Dn, n.axes)

# S3 method for fitCoinertia summary(object, ...)

Value

A list with the following components:

U1

column weights of X.

U2

column weights of Y.

X1

rowscores of X.

X2

rowscores of Y.

lambda

the Eigenvalues (squares of the singular values).

n.axes

number of axes requested.

call

the matched function call.

Arguments

X

\(Q_1\), matrix of expected abundances under row-column independence in the original Y species matrix when treated as a contingency table.

Dp

\(K_1\), species (column) weights for X.

Y

\(Q_2\), matrix of expected abundances under row-column independence in the original X species matrix when treated as a contingency table.

Dq

\(K_2\), species (column) weights for Y.

Dn

site weights \(R_0\).

n.axes

number of axes to calculate the co-inertia analysis for.

object

an object of class coinertia.

axes

the number of axes to display when printing.

...

arguments passed to other functions. Currently ignored.

Author

Original Matlab code by C.J.F. ter Braak and A.P. Schaffers. R port by Gavin L. Simpson.

References

Ter Braak, C.J.F and Schaffers, A.P. (2004) Co-Correspondence Analysis: a new ordination method to relate two community compositions. Ecology 85(3), 834--846

Doledec, S and Chessel, D. (1994) Co-inertia analysis: a method for studying species-environment relationships. Freshwater Biology 31, 277--294

See Also

symcoca for the function that calls fitCoinertia and coinertiaI for co-inertia analysis using identity matrices for \(K_1\), \(K_2\), and \(R_0\)