Learn R Programming

cocorresp (version 0.4-4)

fitted.symcoca: Fitted values of a Symmetric Co-Correpsondence analysis model.

Description

Calculates and extracts the fitted values of a Symmetric Co-Correpsondence analysis model.

Usage

# S3 method for symcoca
fitted(object, which = c("y1","y2"), ...)

Value

A list with the following components:

Y

the fitted values for the “response” matrix.

X

the fitted values for the “predictor” matrix.

nam.dat

a vector containing the names of the “response” and “predictor” matrices respectively. Used for printing the results.

Arguments

object

an object of class "symcoca"

which

character; should the response or predictor scores be plotted. Can be specified in several ways: response choices are one from c("y", "Y", "y1", "response"); predictor choices are one from c("x", "X", "y2", "predictor").

...

arguments to be passed to other methods.

Author

Gavin L. Simpson, based on Matlab code by C.J.F. ter Braak and A.P. Schaffers.

References

Ter Braak, C.J.F and Schaffers, A.P. (2004) Co-Correspondence Analysis: a new ordination method to relate two community compositions. Ecology 85(3), 834--846

See Also

The model fitting function coca

Examples

Run this code
## symmetric CoCA
data(beetles)
data(plants)

## log transform the bettle data
beetles <- log(beetles + 1)

## fit the model
bp.sym <- coca(beetles ~ ., data = plants, method = "symmetric")

## fitted values
bp.fit <- fitted(bp.sym)
bp.fit

## fitted values for beetles only
beetle.fit <- fitted(bp.sym, which = "y1")

Run the code above in your browser using DataLab