powered by
Extracts the residuals of the fitted model of a symmetric CoCA to the response and the predictor.
# S3 method for symcoca resid(object, …)
an object of class "symcoca".
"symcoca"
arguments to be passed to other methods.
A list containing the residuals for the response and the predictor with the following components:
residuals of the fit to the repsonse.
residuals of the fit to the predictor.
symcoca
# NOT RUN { data(bryophyte) data(vascular) bryo.sym <- coca(bryophyte ~ ., data = vascular, method = "symmetric") eps <- resid(bryo.sym) # }
Run the code above in your browser using DataLab