Learn R Programming

cocorresp (version 0.4-6)

resid.symcoca: Extract Model Residuals

Description

Extracts the residuals of the fitted model of a symmetric CoCA to the response and the predictor.

Usage

# S3 method for symcoca
resid(object, ...)

Value

A list containing the residuals for the response and the predictor with the following components:

Y

residuals of the fit to the response.

X

residuals of the fit to the predictor.

Arguments

object

an object of class "symcoca".

...

arguments to be passed to other methods.

Author

Gavin L. Simpson

See Also

symcoca

Examples

Run this code
od <- options(digits = 4)
data(bryophyte)
data(vascular)
bryo.sym <- coca(bryophyte ~ ., data = vascular, method = "symmetric")
eps <- resid(bryo.sym)
options(od)

Run the code above in your browser using DataLab