powered by
Extracts the residuals of the fitted model of a symmetric CoCA to the response and the predictor.
# S3 method for symcoca resid(object, ...)
A list containing the residuals for the response and the predictor with the following components:
residuals of the fit to the response.
residuals of the fit to the predictor.
an object of class "symcoca".
"symcoca"
arguments to be passed to other methods.
Gavin L. Simpson
symcoca
od <- options(digits = 4) data(bryophyte) data(vascular) bryo.sym <- coca(bryophyte ~ ., data = vascular, method = "symmetric") eps <- resid(bryo.sym) options(od)
Run the code above in your browser using DataLab